if (IsAddOnLoaded("Titan") and not IsAddOnLoaded("FuBar")) then
    -- Do not load if Titanbar is loaded
    print("No FuBar found or TitanPanel loaded, quiting FubarAddon");
    return
end

local addonName = ...;

local beql = LibStub("AceAddon-3.0"):GetAddon("beql");
local beqlIcon = beql:NewModule(addonName);

local L = LibStub("AceLocale-3.0"):GetLocale("beql");
local AceConfigDialog = LibStub("AceConfigDialog-3.0");

local beqlLDB = LibStub("LibDataBroker-1.1"):NewDataObject(addonName, {
    type = "data source",
    text = "beql",
    icon = "Interface\\Icons\\INV_Letter_03"
})

local iconFrame = LibStub("LibDBIcon-1.0")

-- Fubar Options

local beqlfubar = {
    desc = L["FubarPlugin Config"],
    name = L["FubarPlugin Config"],
    type = 'group',
    args = {
        hideplugin = {
            desc = L["Hide the plugin from the panel or minimap, leaving the addon running."],
            get = function(info)
                return beql.db.profile.fubar.HidePlugin
            end,
            name = L["Hide plugin"],
            order = 1,
            set = function(info, newval)
                beql.db.profile.fubar.HidePlugin = newval;
				beqlIcon:OnEnable();
            end,
            type = 'toggle',
        },
        headline = {
            order = 2,
            type = 'header',
        },
        ShowTooltip = {
            desc = L["Shows the tooltip on mousover this plugin"], --L["Attach the plugin to the minimap instead of the panel."],
            disabled = function(info)
                return beql.db.profile.fubar.HidePlugin
            end,
            get = function(info)
                return beql.db.profile.fubar.ShowTooltip
            end,
            name = L["Show FuBar Tooltip"], --L["Attach to minimap"],
            order = 6,
            set = function(info, newval)
                beql.db.profile.fubar.ShowTooltip = newval
            end,
            type = 'toggle',
        },
        MinimapPosition = {
            desc = L["Minimap position"],
            disabled = function(info)
                return beql.db.profile.fubar.HidePlugin
            end,
            get = function(info)
                return beql.db.profile.fubar.minimapPos
            end,
            min = 1,
            max = 360,
            name = L["Minimap position"],
            order = 10,
            set = function(info, newval)
                beql.db.profile.fubar.minimapPos = newval;
                iconFrame:Refresh(addonName);
            end,
            step = 1,
            type = 'range',
        }
    }
}

function beqlIcon:OnInitialize()
    iconFrame:Register(addonName, beqlLDB, beql.db.profile.fubar);

    local mainOptions = beql:getMainOptionsTable();

    mainOptions.args.fubar = beqlfubar;
    beql.optionsFrames.fubar = AceConfigDialog:AddToBlizOptions(beql.baseName, L["FubarPlugin Config"], beql.baseName, "fubar");

    iconFrame:Hide(addonName)
end

function beqlIcon:OnEnable()
    if (beql.db.profile.fubar.HidePlugin) then
        iconFrame:Hide(addonName)
    else
        iconFrame:Show(addonName)
    end

    beql:debugprint("enable beqlIcon");
end

function beqlLDB:OnClick(button) 
    if (IsShiftKeyDown()) then
        beql:OpenBlizzardOption("main")
    elseif (button == 'RightButton') then
        beql:OpenBlizzardOption("fubar")
    else
        ToggleFrame(QuestLogFrame);
    end
end
    
function beqlLDB:OnTooltipShow()
    if (not beql.db.profile.fubar.ShowTooltip) then
        return;
    end

    iconFrame.tooltip:SetOwner(iconFrame:GetMinimapButton(addonName), "ANCHOR_BOTTOMLEFT", 30, 0)

    local questEntries = select(2, GetNumQuestLogEntries())
    local numfinished = 0 --select(2, beqlQ:GetNumQuests())

    -- title
    iconFrame.tooltip:AddLine(addonName)
    iconFrame.tooltip:AddLine(" ") -- spacer

    -- num quests
    iconFrame.tooltip:AddDoubleLine(L["|cffffffffQuests|r"], questEntries)

    -- num watched quests
    iconFrame.tooltip:AddDoubleLine(L["|cffff8000Tracked Quests|r"], GetNumQuestWatches())

    -- num completed quests
    iconFrame.tooltip:AddDoubleLine(L["|cff00d000Completed Quests|r"], numfinished)
    iconFrame.tooltip:AddLine(" ") -- spacer

    -- tooltip hint
    iconFrame.tooltip:AddLine(L["|cffeda55fClick|r to open Quest Log and |cffeda55fShift+Click|r to open Waterfall config"] .. L[". |cffeda55fRightclick|r to open FuBar config."], 0, 1, 0, true)

    iconFrame.tooltip:Show()
end

-- EOF --
